"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerOrganisationService = void 0;
const request_1 = require("../core/request");
class RunnerOrganisationService {
    /**
     * Get all
     * Lists all runnerOrganisations.
     * @result ResponseRunnerOrganisation
     * @throws ApiError
     */
    static async runnerOrganisationControllerGetAll() {
        const result = await request_1.request({
            method: 'GET',
            path: `/api/organisations`,
        });
        return result.body;
    }
    /**
     * Post
     * Create a new runnerOrganisation object (id will be generated automagicly).
     * @param requestBody CreateRunnerOrganisation
     * @result ResponseRunnerOrganisation
     * @throws ApiError
     */
    static async runnerOrganisationControllerPost(requestBody) {
        const result = await request_1.request({
            method: 'POST',
            path: `/api/organisations`,
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Get one
     * Returns a runnerOrganisation of a specified id (if it exists)
     * @param id
     * @result ResponseRunnerOrganisation
     * @throws ApiError
     */
    static async runnerOrganisationControllerGetOne(id) {
        const result = await request_1.request({
            method: 'GET',
            path: `/api/organisations/${id}`,
        });
        return result.body;
    }
    /**
     * Put
     * Update a runnerOrganisation object (id can't be changed).
     * @param id
     * @param requestBody RunnerOrganisation
     * @result ResponseRunnerOrganisation
     * @throws ApiError
     */
    static async runnerOrganisationControllerPut(id, requestBody) {
        const result = await request_1.request({
            method: 'PUT',
            path: `/api/organisations/${id}`,
            body: requestBody,
        });
        return result.body;
    }
    /**
     * Remove
     * Delete a specified runnerOrganisation (if it exists).
     * @param id
     * @param force
     * @result ResponseRunnerOrganisation
     * @result ResponseEmpty
     * @throws ApiError
     */
    static async runnerOrganisationControllerRemove(id, force) {
        const result = await request_1.request({
            method: 'DELETE',
            path: `/api/organisations/${id}`,
            query: {
                'force': force,
            },
        });
        return result.body;
    }
}
exports.RunnerOrganisationService = RunnerOrganisationService;
