import type { CreateUserGroup } from '../models/CreateUserGroup';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { UserGroup } from '../models/UserGroup';
import type { UserGroupNotFoundError } from '../models/UserGroupNotFoundError';
export declare class UserGroupService {
    /**
     * Get all
     * Lists all usergroups.
     * @result UserGroup
     * @throws ApiError
     */
    static userGroupControllerGetAll(): Promise<Array<UserGroup>>;
    /**
     * Post
     * Create a new usergroup object (id will be generated automagicly).
     * @param requestBody CreateUserGroup
     * @result any
     * @throws ApiError
     */
    static userGroupControllerPost(requestBody?: CreateUserGroup): Promise<(UserGroup | UserGroupNotFoundError)>;
    /**
     * Get one
     * Returns a usergroup of a specified id (if it exists)
     * @param id
     * @result UserGroup
     * @throws ApiError
     */
    static userGroupControllerGetOne(id: number): Promise<UserGroup>;
    /**
     * Put
     * Update a usergroup object (id can't be changed).
     * @param id
     * @param requestBody UserGroup
     * @result UserGroup
     * @throws ApiError
     */
    static userGroupControllerPut(id: number, requestBody?: UserGroup): Promise<UserGroup>;
    /**
     * Remove
     * Delete a specified usergroup (if it exists).
     * @param id
     * @result UserGroup
     * @result ResponseEmpty
     * @throws ApiError
     */
    static userGroupControllerRemove(id: number): Promise<UserGroup | ResponseEmpty>;
}
