import type { CreateUser } from '../models/CreateUser';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { User } from '../models/User';
import type { UserGroupNotFoundError } from '../models/UserGroupNotFoundError';
export declare class UserService {
    /**
     * Get all
     * Lists all users.
     * @result User
     * @throws ApiError
     */
    static userControllerGetAll(): Promise<Array<User>>;
    /**
     * Post
     * Create a new user object (id will be generated automagicly).
     * @param requestBody CreateUser
     * @result any
     * @throws ApiError
     */
    static userControllerPost(requestBody?: CreateUser): Promise<(User | UserGroupNotFoundError)>;
    /**
     * Get one
     * Returns a user of a specified id (if it exists)
     * @param id
     * @result User
     * @throws ApiError
     */
    static userControllerGetOne(id: number): Promise<User>;
    /**
     * Put
     * Update a user object (id can't be changed).
     * @param id
     * @param requestBody User
     * @result User
     * @throws ApiError
     */
    static userControllerPut(id: number, requestBody?: User): Promise<User>;
    /**
     * Remove
     * Delete a specified runner (if it exists).
     * @param id
     * @result User
     * @result ResponseEmpty
     * @throws ApiError
     */
    static userControllerRemove(id: number): Promise<User | ResponseEmpty>;
}
